@@ -205,7 +205,7 @@ def populate_pkg_dir(
 
     if not skip_docsrc_gen:
         # TODO: Figure out epythet and wads relationship -- right now, there's a reflexive dependency
-        from epythet.docs_gen.setup_docsrc import make_docsrc
+        from epythet.setup_docsrc import make_docsrc
 
         make_docsrc(pkg_dir, verbose)
 
